@@ -11,6 +11,9 @@ import importlib
 
 from .logger import Logger
 
+from .log_levels import LogLevel
+from .sys_procolls import SysProtocolls
+
 from .handler.filehandler import FileHandler
 from .handler.consolehandler import ConsoleHandler
 from .handler.jsonhandler import JSONHandler
@@ -18,18 +21,23 @@ from .handler.sqlhandler import SQLHandler
 from .handler.csvhandler import CSVHandler
 from .handler.syshandler import SysHandler
 
-from .log_levels import LogLevel
-from .sys_procolls import SysProtocolls
-
 from .error.server_unreachable_error import ServerUnreachableError
 from .error.server_method_call_error import ServerMethodCallError
 from .error.client_method_call_error import ClientMethodCallError
+from .error.invalid_log_level_error import InvalidLogLevelError
+from .error.invalid_handler_method_error import InvalidHandlerMethodError
+from .error.handler_not_found_error import HandlerNotFoundError
 
-__version__ = "1.3.2"
+
+__version__ = "1.4.1"
 __all__ = [
     # Bacis
     "Logger",
 
+    # Enum
+    "LogLevel",
+    "SysProtocolls",
+
     # Hander
     "Handler",
     "FileHandler",
@@ -39,14 +47,13 @@ __all__ = [
     "CSVHandler",
     "SysHandler",
 
-    # Enum
-    "LogLevel",
-    "SysProtocolls",
-
     # Error
     "ServerUnreachableError",
     "ServerMethodCallError",
-    "ClientMethodCallError"
+    "ClientMethodCallError",
+    "InvalidLogLevelError",
+    "InvalidHandlerMethodError",
+    "HandlerNotFoundError"
     ]
 
 __license__ = "MIT"
@@ -57,22 +64,29 @@ def hello_from_loggingpython() -> None:
     Outputs a welcome message containing information about the
     loggingpython community.
     """
-    print(f"""Hello from the loggingpython-community.
+    print(f"""
+Hello from the loggingpython-community.
 We also use other libs, for a list of all libs look here: \
 https://github.com/loggingpython-Community/loggingpython/wiki/Lib-List
 Version: {__version__}
-PyPi: https://pypi.org/project/loggingpython
-GitHub: https://github.com/loggingpython-Community/loggingpython""")
+GitHub: https://github.com/loggingpython-Community/loggingpython
+""")
 
 
-def getLogger(name: str = "Root-Logger") -> Logger:
+def getLogger(name: str = "Root-Logger",
+              time_format: str = None,
+              min_loglevel: LogLevel = None,
+              max_loglevel: LogLevel = None) -> Logger:
     """
-        Creates and returns an instance of the logger.
+    Creates and returns an instance of the logger.
 
-        Returns:
-            Logger: An instance of the logger.
-        """
-    return Logger(name)
+    Returns:
+        Logger: An instance of the logger.
+    """
+    return Logger(name=name,
+                  time_format=time_format,
+                  min_loglevel=min_loglevel,
+                  max_loglevel=max_loglevel)
 
 
 def getBasicLogger() -> Logger:
@@ -100,10 +114,8 @@ def get_all_handlers() -> dict[str]:
     handlers = {}
     for handler_name in __all__:
         if handler_name.endswith("Handler"):
-            # Adjust the module name to correctly resolve the import path
             module_name = f"{__name__}.handler.{handler_name.lower()}"
             try:
-                # Use importlib.import_module for dynamic import
                 handler_module = importlib.import_module(module_name)
                 handler_class = getattr(handler_module, handler_name)
                 handlers[handler_name] = handler_class
