@@ -2,8 +2,9 @@ from typing import TextIO
 from colorama import Fore, Style
 import sys
 
-from ..log_levels import LogLevel
 from .handler import Handler
+from ..log_levels import LogLevel
+from ..error.invalid_log_level_error import InvalidLogLevelError
 
 
 class ConsoleHandler(Handler):
@@ -16,7 +17,8 @@ class ConsoleHandler(Handler):
     severity and allows customization of the formatting string.
     """
 
-    def __init__(self, stream: TextIO = sys.stdout,
+    def __init__(self,
+                 stream: TextIO = sys.stdout,
                  logformat_string: str = "%(asctime)s: [%(loggername)s]: \
 [%(loglevel)s]: %(message)s") -> None:
         """
@@ -50,7 +52,10 @@ class ConsoleHandler(Handler):
             record (dict): A dictionary with the details of the log message,
                 including timestamp, logger name, log level and message.
         """
-        formatted_message = self._format_message(record)
+
+        formatted_message_values = self._format_message(record)
+        formatted_message = self.logformat_string % formatted_message_values
+
         color = self._get_color_for_level(record["loglevel"])
         self.stream.write(color + formatted_message + Style.RESET_ALL + '\n')
         self.stream.flush()
@@ -65,7 +70,7 @@ class ConsoleHandler(Handler):
         """
         for level in color_map.keys():
             if level not in LogLevel.__members__:
-                raise ValueError(f"Invalid log level: {level}")
+                raise InvalidLogLevelError(level)
 
         self.color_map.update(color_map)
 
@@ -82,27 +87,6 @@ class ConsoleHandler(Handler):
         """
         return self.color_map.get(loglevel, Fore.WHITE)
 
-    def _format_message(self, record: dict) -> str:
-        """
-        Formats a log message based on the transferred log data set.
-
-        Args:
-            record (dict): A dictionary with the details of the log message.
-
-        Returns:
-            str: The formatted log message.
-        """
-        values = {
-            "loggername": record.get("loggername", ""),
-            "iso_8601_time": record.get("iso_8601_time", ""),
-            "asctime": record.get("asctime", ""),
-            "loglevel": record.get("loglevel", ""),
-            "message": record.get("message", ""),
-        }
-
-        logformat_string = self.logformat_string
-        return logformat_string % values
-
     def __repr__(self) -> str:
         return f"ConsoleHandler({self.name}, {self.logformat_string})"
 
